RTPI - Oxfordshire

Oxontime Links

- Oxontime Home
- Search Options
- News / Status
- SMS Service
- About Oxontime
- Coverage
- Instructions / Help
- Terms of Use
- Text Only

Contact Us

- contact@oxontime.com
- Oxontime RTI
  Oxfordshire County Council
  Speedwell House
  Speedwell Street
  Oxford OX1 1NE

# Search options

To find live departure information on bus services use the search options below and select your required bus stop.

SMS number | 69327545
Stop name | George Street B1View on map
Refresh time | 29/03/2012 14:20:23

Service number | Destination | Departure time | Vehicle accessible | Operator name | CurrentOrder
--- | --- | --- | --- | --- | ---
14A | JR Hospital | DUE | SOX | 14:23
14A | JR Hospital | 3 mins | OBC | 18:15
300 | Pear Tree P&R | 4 mins | OBC | 14:24
S1 | Set Down Only | 13 mins | SOX | 14:33
300 | Pear Tree P&R | 22 mins | OBC | 14:42
300 | Pear Tree P&R | 32 mins | OBC | 14:52
14 | JR Hospital | 33 mins | SOX | 14:53
S1 | Set Down Only | 34 mins | SOX | 14:54
17 | Cutteslowe | 41 mins | SOX | 15:01
S1 | Set Down Only | 42 mins | SOX | 15:02
300 | Pear Tree P&R | 42 mins | OBC | 15:02
300 | Pear Tree P&R | 52 mins | OBC | 15:12
S1 | Set Down Only | 57 mins | SOX | 15:17
S1 | Set Down Only | 72 mins | SOX | 15:32
S1 | Set Down Only | 87 mins | SOX | 15:47
S1 | Set Down Only | 102 mins | SOX | 16:02
S1 | Set Down Only | 117 mins | SOX | 16:17